@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -89,7 +89,8 @@ sub new {
         $opts{AutoCommit} = 0;
         $self->{$db} = CPAN::Testers::Common::DBUtils->new(%opts);
         die "Cannot configure $db database\n" unless($self->{$db});
-        $self->{$db}->{'mysql_enable_utf8'} = 1 if($opts{driver} =~ /mysql/i);
+        $self->{$db}->{'mysql_enable_utf8'}    = 1 if($opts{driver} =~ /mysql/i);
+        $self->{$db}->{'mysql_auto_reconnect'} = 1 if($opts{driver} =~ /mysql/i);
     }
 
     if($cfg->SectionExists('ADMINISTRATION')) {
@@ -524,7 +525,11 @@ sub get_next_guids {
     my ($self,$start,$end) = @_;
     my ($guids);
 
-    $self->_log("PRE time=[".($self->{time}||'')."], last=[".($self->{last}||'')."], start=[".($start||'')."], end=[".($end||'')."]\n");
+    $self->{time} ||= 0;
+    $self->{last} ||= 0;
+    $start ||= 0;
+
+    $self->_log("PRE time=[$self->{time}], last=[$self->{last}], start=[".($start||'')."], end=[".($end||'')."]\n");
 
     if($start) {
         $self->{time}       = $start;
@@ -555,14 +560,14 @@ sub get_next_guids {
         }
     }
 
-    $self->_log("START time=[$self->{time}], last=[".($self->{last}||'')."]\n");
+    $self->_log("START time=[$self->{time}], last=[$self->{last}]\n");
     $self->{last} = $self->{time};
 
     eval {
 #        if($self->{time_to}) {
 #            $guids = $self->{librarian}->search(
 #                'core.type'         => 'CPAN-Testers-Report',
-#                'core.update_time'  => { -and => { [ ">=", $self->{time} ], [ "<=", $self->{time_to} ] } },
+#                'core.update_time'  => { -and => { ">=" => $self->{time}, "<=" => $self->{time_to} } },
 #                '-asc'              => 'core.update_time',
 #                '-limit'            => $self->{poll_limit},
 #            );
@@ -1079,8 +1084,11 @@ sub _consume_reports {
         my ($update,$prev,$last) = ($start,$start,$start);
         my @times = ();
 
+        my $saved = 0;
         while($update le $end) {
-            $self->_log("UPDATE: update=$update, end=$end\n");
+            $self->_log("UPDATE: update=$update, end=$end, saved=$saved, guids=".(scalar(@guids))."\n");
+
+            last    if($saved >= @guids);
 
             # get list of guids from last update date
             my $guids = $self->get_next_guids($update,$end);
@@ -1106,6 +1114,7 @@ sub _consume_reports {
                 if(my $time = $self->already_saved($guid)) {
                     $self->_log(".. already saved\n");
                     $update = $time;
+                    $saved++;
                     next;
                 }
 
